@@ -1,4 +1,8 @@
 from lyrebird import on_request
+from lyrebird.checker import CheckerCategory
+
+TITLE = '<示例脚本>在Request中添加Param'
+CATEGORY = CheckerCategory.EDITOR
 
 @on_request(rules={
     "request.url": "(?=.*poi/detail)"
@@ -8,3 +12,5 @@ def add_request_param(flow):
         flow['request']['url'] += '&param=1'
     else:
         flow['request']['url'] += '?param=1'
+
+
