@@ -35,8 +35,20 @@ class DataManager:
         self.snapshot_import_cache = {}
         self.SNAPSHOT_SUFFIX = '.lb'
         self.COPY_NODE_NAME_SUFFIX = ' - copy'
-        self.SNAPSHOT_WORKSPACE = None
         self.root = self.get_default_root()
+        self._snapshot_workspace = None
+
+    @property
+    def snapshot_workspace(self):
+        if not self._snapshot_workspace:
+            self._snapshot_workspace = Path(application._cm.ROOT) / 'snapshot'
+        if not self._snapshot_workspace.exists():
+            self._snapshot_workspace.mkdir()
+        return self._snapshot_workspace
+
+    @snapshot_workspace.setter
+    def snapshot_workspace(self, workspace):
+        self._snapshot_workspace = workspace
 
     def get_default_root(self):
         return {
@@ -202,6 +214,7 @@ class DataManager:
     def _format_respose_data(self, flow):
         # TODO render mock data before response, support more functions
         params = {
+            'config': config,
             'ip': config.get('ip'),
             'port': config.get('mock.port'),
             'today': datetime.date.today(),
@@ -220,7 +233,7 @@ class DataManager:
             return False
         for rule_key, pattern in rules.items():
             targets = self._get_rule_targets(rule_key, flow)
-            if not targets:
+            if targets == []:
                 return False
             if not self._is_target_pattern_matched(pattern, targets):
                 return False
@@ -229,17 +242,12 @@ class DataManager:
     def _get_rule_targets(self, rule_key, flow):
         search_res = jsonpath.search(flow, rule_key)
         if not search_res:
-            return None
-        return [s.node for s in search_res if s.node]
+            return []
+        return [s.node for s in search_res]
 
     def _is_target_pattern_matched(self, pattern, targets):
         for target in targets:
-            try:
-                search_result = re.search(pattern, target)
-            except:
-                logger.warning(f'Illegal regular match in mock data!\n {traceback.format_exc()}')
-                return False
-            if not search_result:
+            if not utils.TargetMatch.is_match(target, pattern):
                 return False
         return True
 
@@ -737,12 +745,8 @@ class DataManager:
                 path.unlink()
 
     def _get_snapshot_path(self):
-        if not self.SNAPSHOT_WORKSPACE:
-            self.SNAPSHOT_WORKSPACE = Path(application._cm.ROOT) / 'snapshot'
-        if not self.SNAPSHOT_WORKSPACE.exists():
-            self.SNAPSHOT_WORKSPACE.mkdir()
         temp_dir_name = f"{time.strftime('%Y-%m-%d-%H-%M-%S', time.localtime())}-{str(uuid.uuid4())}"
-        snapshot_path = self.SNAPSHOT_WORKSPACE / temp_dir_name
+        snapshot_path = self.snapshot_workspace / temp_dir_name
         snapshot_path.mkdir()
         return snapshot_path
 
